@@ -23,15 +23,17 @@ Usage:
 from .mgmt import *
 from .resources import *
 from .builder import *
+from .tools import *
 
 # Create default configuration for direct imports (backward compatibility)
 from .builder.directors import AzureManagementDirector, AzureResourceDirector
 
-
 __all__ = [
     # Builder patterns (via builder module imports)
     "ConfigurationSetupBuilder", "ConfigurationSetupDirector", "EnvironmentConfiguration",
     "AzureManagementBuilder", "AzureResourceBuilder", 
     "AzureManagementConfiguration", "AzureResourceConfiguration", "AzureConfiguration",
     "AzureManagementDirector", "AzureConfigurationDirector", "AzureResourceDirector",
+    # Tools
+    "CosmosPromptManager", "create_cosmos_prompt_manager",
 ]
\ No newline at end of file
