@@ -68,6 +68,7 @@ from ..mgmt.local_env_manager import create_local_env_manager
 from ..mgmt.logging import create_app_logger, create_function_logger
 from ..resources.keyvault import create_azure_keyvault
 from ..resources.storage import create_azure_storage
+from ..resources.cosmosdb import create_azure_cosmosdb
 
 
 @dataclass
@@ -384,11 +385,14 @@ class AzureManagementConfiguration:
 class AzureResourceConfiguration:
     """Resource services configuration."""
     storage_accounts: Dict[str, Any] = None
+    cosmosdb_clients: Dict[str, Any] = None
     
     def __post_init__(self):
-        """Initialize storage_accounts as empty dict if None."""
+        """Initialize storage_accounts and cosmosdb_clients as empty dicts if None."""
         if self.storage_accounts is None:
             self.storage_accounts = {}
+        if self.cosmosdb_clients is None:
+            self.cosmosdb_clients = {}
     
     def validate(self) -> bool:
         """Validate resource configuration."""
@@ -406,6 +410,19 @@ class AzureResourceConfiguration:
     def storage_account(self) -> Optional[Any]:
         """Backward compatibility property for single storage account access."""
         return self.get_primary_storage()
+    
+    def get_cosmosdb(self, name: str = "default") -> Optional[Any]:
+        """Get CosmosDB client by name."""
+        return self.cosmosdb_clients.get(name)
+    
+    def get_primary_cosmosdb(self) -> Optional[Any]:
+        """Get the primary/default CosmosDB client."""
+        return self.get_cosmosdb("default") or next(iter(self.cosmosdb_clients.values()), None)
+    
+    @property
+    def cosmosdb_client(self) -> Optional[Any]:
+        """Backward compatibility property for single CosmosDB client access."""
+        return self.get_primary_cosmosdb()
 
 
 @dataclass
@@ -608,6 +625,7 @@ class AzureResourceBuilder:
         self._management = management_config
         self._env_config = env_config
         self._storage_accounts: Dict[str, Any] = {}
+        self._cosmosdb_clients: Dict[str, Any] = {}
         self._stage = ResourceInitializationStage.NOT_STARTED
     
     def with_storage(self, name: str = "default", account_url: Optional[str] = None, 
@@ -670,10 +688,58 @@ class AzureResourceBuilder:
         self._stage = ResourceInitializationStage.STORAGE_READY
         return self
     
+    def with_cosmosdb(self, name: str = "default", endpoint: Optional[str] = None,
+                     auto_construct_endpoint: bool = True) -> 'AzureResourceBuilder':
+        """Initialize named CosmosDB client.
+        
+        Reads configuration from environment variables if not provided:
+        - COSMOS_ENDPOINT: CosmosDB endpoint URL (default client only)
+        """
+        if name in self._cosmosdb_clients:
+            raise ValueError(f"CosmosDB client '{name}' already configured")
+        
+        # Read environment variables directly for default cosmosdb, use provided values for named ones
+        cosmos_endpoint = endpoint or (os.getenv("COSMOS_ENDPOINT") if name == "default" else None)
+        
+        # Auto-construct CosmosDB endpoint from Key Vault secrets if requested
+        if auto_construct_endpoint and self._management.keyvault and not cosmos_endpoint:
+            try:
+                project_code = self._management.keyvault.get_secret("project-code")
+                azure_environment = self._management.keyvault.get_secret("resource-group-environment")
+                
+                # Different naming patterns based on cosmosdb client name
+                if name == "default":
+                    cosmos_account_name = f"coscas-promptmgmt-{project_code}-{azure_environment}"
+                else:
+                    cosmos_account_name = f"coscas-{name}-{project_code}-{azure_environment}"
+                    
+                cosmos_endpoint = f"https://{cosmos_account_name}.documents.azure.com:443/"
+                self._management.logger.info(f"Auto-constructed CosmosDB endpoint for '{name}': {cosmos_endpoint}")
+            except Exception as e:
+                self._management.logger.warning(f"Failed to auto-construct CosmosDB endpoint for '{name}': {e}")
+                cosmos_endpoint = None
+        
+        if cosmos_endpoint:
+            cosmosdb_client = create_azure_cosmosdb(
+                endpoint=cosmos_endpoint,
+                azure_identity=self._management.identity,
+                service_name=self._env_config.service_name,
+                service_version=self._env_config.service_version,
+                logger=self._management.logger,
+                connection_string=self._env_config.logger_connection_string,  # Share logger connection
+            )
+            self._cosmosdb_clients[name] = cosmosdb_client
+            self._management.logger.info(f"CosmosDB client '{name}' initialized: {cosmos_endpoint}")
+        else:
+            self._management.logger.info(f"No CosmosDB endpoint configured for '{name}'. Skipping CosmosDB initialization.")
+        
+        return self
+    
     def build(self) -> AzureResourceConfiguration:
         """Build resource configuration."""
         config = AzureResourceConfiguration(
-            storage_accounts=self._storage_accounts.copy()
+            storage_accounts=self._storage_accounts.copy(),
+            cosmosdb_clients=self._cosmosdb_clients.copy()
         )
         
         config.validate()
@@ -684,6 +750,9 @@ class AzureResourceBuilder:
                 "storage_accounts_count": len(self._storage_accounts),
                 "storage_account_names": list(self._storage_accounts.keys()),
                 "primary_storage_enabled": bool(config.get_primary_storage()),
+                "cosmosdb_clients_count": len(self._cosmosdb_clients),
+                "cosmosdb_client_names": list(self._cosmosdb_clients.keys()),
+                "primary_cosmosdb_enabled": bool(config.get_primary_cosmosdb()),
             }
         )
         
