@@ -380,6 +380,148 @@ class TestMultipleKeyVaults:
         assert keys_call['enable_certificates'] is False
 
 
+class TestCosmosDBBuilder:
+    """Test CosmosDB functionality in resource builder."""
+
+    @patch('azpaddypy.builder.configuration.create_azure_cosmosdb')
+    def test_resource_builder_with_cosmosdb(self, mock_cosmosdb):
+        """Test resource builder with CosmosDB."""
+        from azpaddypy.builder import AzureResourceBuilder, AzureManagementConfiguration
+        from azpaddypy.resources.cosmosdb import AzureCosmosDB
+
+        mock_cosmosdb.return_value = Mock(spec=AzureCosmosDB)
+
+        # Create mock management config
+        mgmt_config = Mock(spec=AzureManagementConfiguration)
+        mgmt_config.validate.return_value = True
+        mgmt_config.logger = Mock(spec=AzureLogger)
+        mgmt_config.identity = Mock(spec=AzureIdentity)
+        mgmt_config.keyvault = None
+
+        env_config = create_mock_env_config()
+        
+        with patch.dict(os.environ, {"COSMOS_ENDPOINT": "https://test.documents.azure.com:443/"}, clear=False):
+            config = (AzureResourceBuilder(mgmt_config, env_config)
+                      .with_cosmosdb()
+                      .build())
+
+        assert config.cosmosdb_client is not None
+        assert config.get_cosmosdb("default") is not None
+        assert config.validate()
+        mock_cosmosdb.assert_called_once()
+
+    @patch('azpaddypy.builder.configuration.create_azure_cosmosdb')
+    def test_multiple_cosmosdb_clients(self, mock_cosmosdb):
+        """Test multiple CosmosDB clients configuration."""
+        from azpaddypy.builder import AzureResourceBuilder, AzureManagementConfiguration
+        from azpaddypy.resources.cosmosdb import AzureCosmosDB
+
+        mock_cosmosdb.return_value = Mock(spec=AzureCosmosDB)
+
+        mgmt_config = Mock(spec=AzureManagementConfiguration)
+        mgmt_config.validate.return_value = True
+        mgmt_config.logger = Mock(spec=AzureLogger)
+        mgmt_config.identity = Mock(spec=AzureIdentity)
+        mgmt_config.keyvault = None
+
+        env_config = create_mock_env_config()
+        config = (AzureResourceBuilder(mgmt_config, env_config)
+                  .with_cosmosdb("default", "https://default.documents.azure.com:443/")
+                  .with_cosmosdb("prod", "https://prod.documents.azure.com:443/")
+                  .with_cosmosdb("dev", "https://dev.documents.azure.com:443/")
+                  .build())
+
+        assert len(config.cosmosdb_clients) == 3
+        assert config.get_cosmosdb("default") is not None
+        assert config.get_cosmosdb("prod") is not None
+        assert config.get_cosmosdb("dev") is not None
+        assert config.get_primary_cosmosdb() is not None
+        assert config.cosmosdb_client is not None  # Backward compatibility
+
+        # Verify creation was called for each cosmosdb
+        assert mock_cosmosdb.call_count == 3
+
+    @patch('azpaddypy.builder.configuration.create_azure_cosmosdb')
+    def test_cosmosdb_auto_construct_endpoint(self, mock_cosmosdb):
+        """Test CosmosDB endpoint auto-construction from KeyVault."""
+        from azpaddypy.builder import AzureResourceBuilder, AzureManagementConfiguration
+        from azpaddypy.resources.cosmosdb import AzureCosmosDB
+
+        mock_cosmosdb.return_value = Mock(spec=AzureCosmosDB)
+
+        # Create mock keyvault with project secrets
+        mock_keyvault = Mock()
+        mock_keyvault.get_secret.side_effect = lambda key: {
+            "project-code": "myproject",
+            "resource-group-environment": "dev"
+        }.get(key)
+
+        mgmt_config = Mock(spec=AzureManagementConfiguration)
+        mgmt_config.validate.return_value = True
+        mgmt_config.logger = Mock(spec=AzureLogger)
+        mgmt_config.identity = Mock(spec=AzureIdentity)
+        mgmt_config.keyvault = mock_keyvault
+
+        env_config = create_mock_env_config()
+        config = (AzureResourceBuilder(mgmt_config, env_config)
+                  .with_cosmosdb("default")  # Should auto-construct
+                  .build())
+
+        # Verify auto-constructed endpoint was used
+        call_args = mock_cosmosdb.call_args[1]
+        expected_endpoint = "https://coscas-promptmgmt-myproject-dev.documents.azure.com:443/"
+        assert call_args['endpoint'] == expected_endpoint
+
+    @patch('azpaddypy.builder.configuration.create_azure_cosmosdb')
+    def test_duplicate_cosmosdb_name_fails(self, mock_cosmosdb):
+        """Test that duplicate CosmosDB names raise an error."""
+        from azpaddypy.builder import AzureResourceBuilder, AzureManagementConfiguration
+        from azpaddypy.resources.cosmosdb import AzureCosmosDB
+
+        mock_cosmosdb.return_value = Mock(spec=AzureCosmosDB)
+
+        mgmt_config = Mock(spec=AzureManagementConfiguration)
+        mgmt_config.validate.return_value = True
+        mgmt_config.logger = Mock(spec=AzureLogger)
+        mgmt_config.identity = Mock(spec=AzureIdentity)
+
+        env_config = create_mock_env_config()
+        builder = (AzureResourceBuilder(mgmt_config, env_config)
+                  .with_cosmosdb("default", "https://first.documents.azure.com:443/"))
+
+        # Should fail on duplicate name
+        with pytest.raises(ValueError, match="CosmosDB client 'default' already configured"):
+            builder.with_cosmosdb("default", "https://second.documents.azure.com:443/")
+
+    def test_cosmosdb_backward_compatibility(self):
+        """Test backward compatibility properties for CosmosDB."""
+        from azpaddypy.builder import AzureResourceConfiguration
+        from azpaddypy.resources.cosmosdb import AzureCosmosDB
+
+        config = AzureResourceConfiguration(cosmosdb_clients={})
+
+        # No CosmosDB clients configured
+        assert config.cosmosdb_client is None
+        assert config.get_cosmosdb("default") is None
+        assert config.get_primary_cosmosdb() is None
+
+        # Add some CosmosDB clients
+        default_cosmos = Mock(spec=AzureCosmosDB)
+        prod_cosmos = Mock(spec=AzureCosmosDB)
+        other_cosmos = Mock(spec=AzureCosmosDB)
+        
+        config.cosmosdb_clients["default"] = default_cosmos
+        config.cosmosdb_clients["prod"] = prod_cosmos
+        config.cosmosdb_clients["other"] = other_cosmos
+
+        # Test backward compatibility
+        assert config.cosmosdb_client is default_cosmos
+        assert config.get_cosmosdb("default") is default_cosmos
+        assert config.get_cosmosdb("prod") is prod_cosmos
+        assert config.get_cosmosdb("other") is other_cosmos
+        assert config.get_primary_cosmosdb() is default_cosmos
+
+
 class TestMultipleStorageAccounts:
     """Test multiple storage account functionality."""
 
@@ -635,6 +777,8 @@ class TestDirectorPatterns:
         assert default_config.local_env_manager is not None
 
 
+
+
 class TestConfigurationValidation:
     """Test configuration validation."""
 
@@ -692,6 +836,27 @@ class TestConfigurationValidation:
         assert config.get_storage("backup") is not None
         assert config.get_primary_storage() is not None
 
+        # Test CosmosDB configuration
+        config = AzureResourceConfiguration(cosmosdb_clients={"default": Mock()})
+        assert config.validate()
+        assert config.cosmosdb_client is not None
+
+        # Test multiple CosmosDB clients
+        config = AzureResourceConfiguration(cosmosdb_clients={"default": Mock(), "prod": Mock()})
+        assert config.validate()
+        assert config.get_cosmosdb("default") is not None
+        assert config.get_cosmosdb("prod") is not None
+        assert config.get_primary_cosmosdb() is not None
+
+        # Test combined storage and CosmosDB configuration
+        config = AzureResourceConfiguration(
+            storage_accounts={"default": Mock()},
+            cosmosdb_clients={"default": Mock()}
+        )
+        assert config.validate()
+        assert config.storage_account is not None
+        assert config.cosmosdb_client is not None
+
     def test_combined_config_validation(self):
         """Test combined configuration validation."""
         from azpaddypy.builder import AzureConfiguration, AzureManagementConfiguration, AzureResourceConfiguration
